
%total deaths
dt_totaldeaths = datetime('01/Mar/2020') : datetime('14/Nov/2020'); 
% Put data into timetable
tt = timetable(dt_totaldeaths',totaldeaths_daily,'VariableNames',{'TotalDeaths'});
% Calculate weekly total deaths
totaldeaths_weekly = retime(tt,'Weekly','lastvalue');


%dummy
dt_dummy = datetime('01/Jan/2020') : datetime('14/Nov/2020'); 
tt = timetable(dt_dummy',NaN*ones(numel(dt_dummy),1),'VariableNames',{'Dummy'});
dummy_weekly = retime(tt,'Weekly','mean');


%syncronize
sync_data_weekly=synchronize(totaldeaths_weekly,dummy_weekly);

dt_totaldeaths = datetime('01/Mar/2020') : datetime('14/Nov/2020'); 
% Put data into timetable
tt = timetable(dt_totaldeaths',totaldeaths_daily,'VariableNames',{'TotalDeaths'});
% Calculate weekly total deaths
totaldeaths_weekly = retime(tt,'Weekly','lastvalue');

%time shifter for model simulation data. Must be 0 or 4 for now 
shiftweeks=4; 

%model data
ModelDeaths=(Du+Dk)*100;
ModelCons=aggC;
ModelConsMonthly=100*(mean(reshape(ModelCons(1:400),4,100))'-ModelCons(1))/(ModelCons(1));

if shiftweeks>0
    ModelDeaths=[NaN*ones(shiftweeks,1);ModelDeaths(1:end-shiftweeks)];
    ModelConsMonthly=[NaN*ones(shiftweeks/4,1);ModelConsMonthly(1:end-shiftweeks/4)];
end

figure;
sub1=subplot(2,2,1);
plot(sync_data_weekly.Time,100*sync_data_weekly{:,1}/pop1,'k-','LineWidth',2),hold on
plot(sync_data_weekly.Time,ModelDeaths(1:numel(sync_data_weekly.Time)),'m--','LineWidth',2),hold on
xlim([dt_dummy(1) dt_dummy(end)])
xtickformat('MMM')
xticks(dt_dummy(1) : calmonths(1) : dt_dummy(end))
box off;
title('Total Deaths (Weekly)');
ylabel('% of Initial Population');
set(gca,'FontSize',12);
legend('Data (Total Deaths/(Pop>16))','Model','Location','Northwest');
legend boxoff;
axis tight


sub2=subplot(2,2,2);
plot([1+shiftweeks/4:11],100*(cons_monthly(1+shiftweeks/4:11)-cons_monthly(1))/cons_monthly(1),'k-','LineWidth',2),hold on
plot([1+shiftweeks/4:11],ModelConsMonthly(1+shiftweeks/4:11),'m--','LineWidth',2),hold on
plot([1+shiftweeks/4:11],0*ModelConsMonthly(1+shiftweeks/4:11),'b:','LineWidth',1),hold on
xticks([1+shiftweeks/4:11])
if shiftweeks==4
    xticklabels({'Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov \newline 2020'})
elseif shiftweeks==0
    xticklabels({'Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov \newline 2020'})
else
    error('shiftweek > 4 not implemented yet')
end
box off;
title('Consumption (Monthly)');
ylabel('% Dev. from Jan 2020');
set(gca,'FontSize',12);
legend('Data (Real Pers. Cons. Exp.)','Model','Location','Southeast');
legend boxoff;
axis tight


RnotSIRmacro=(Tk(2)+Tu(2))/(Ik(1)+Iu(1))/(pir+pid);
subplot(2,2,3:4)
plot(RnotSIRmacro*(Sk(1:500)+Su(1:500)),'b-','LineWidth',2); hold on
plot([1:500],ones(500,1),'k:','LineWidth',1);
title('Rnot');
box off
set(gca,'FontSize',12);
legend boxoff;
axis tight
xlabel('Weeks');
axis([0 300 0.75 2.05]);


%suptitle('Figure XX: Level and Growth Rate of Deaths');


orient landscape

print -dpdf -fillpage model_vs_data_deaths


save all_restults_testing_after_plots
